@@ -1,4 +1,4 @@
-dd_ML = function(brts, initparsopt = if(ddmodel < 5) {c(0.1+bd(sort(as.numeric(brts),decreasing = TRUE))$r1/(1-bd(sort(as.numeric(brts),decreasing = TRUE))$a),0.1,2*(length(brts) + missnumspec))} else {c(0.1+bd(sort(as.numeric(brts),decreasing = TRUE))$r1/(1-bd(sort(as.numeric(brts),decreasing = TRUE))$a),0.1,2*(length(brts) + missnumspec),0.01)}, idparsopt = 1:length(initparsopt), idparsfix = (1:(3 + (ddmodel == 5)))[-idparsopt], parsfix = (ddmodel < 5) * c(0.2,0.1,2*(length(brts) + missnumspec))[-idparsopt] + (ddmodel == 5) * c(0.2,0.1,2*(length(brts) + missnumspec),0)[-idparsopt], res = 10*(1+length(brts)+missnumspec), ddmodel = 1, missnumspec = 0, cond = TRUE, btorph = 1, tol = c(1E-3, 1E-4, 1E-6), maxiter = 1000 * round((1.25)^length(idparsopt)))
+dd_ML = function(brts, initparsopt = if(ddmodel < 5) {c(0.1+bd(sort(as.numeric(brts),decreasing = TRUE))$r1/(1-bd(sort(as.numeric(brts),decreasing = TRUE))$a),0.1,2*(length(brts) + missnumspec))} else {c(0.1+bd(sort(as.numeric(brts),decreasing = TRUE))$r1/(1-bd(sort(as.numeric(brts),decreasing = TRUE))$a),0.1,2*(length(brts) + missnumspec),0.01)}, idparsopt = 1:length(initparsopt), idparsfix = (1:(3 + (ddmodel == 5)))[-idparsopt], parsfix = (ddmodel < 5) * c(0.2,0.1,2*(length(brts) + missnumspec))[-idparsopt] + (ddmodel == 5) * c(0.2,0.1,2*(length(brts) + missnumspec),0)[-idparsopt], res = 10*(1+length(brts)+missnumspec), ddmodel = 1, missnumspec = 0, cond = TRUE, btorph = 1, soc = 2, tol = c(1E-3, 1E-4, 1E-6), maxiter = 1000 * round((1.25)^length(idparsopt)))
 {
 # brts = branching times (positive, from present to past)
 # - max(brts) = crown age
@@ -48,7 +48,7 @@ flush.console()
 trparsopt = initparsopt/(1 + initparsopt)
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
-pars2 = c(res,ddmodel,cond,btorph,0,tol,maxiter)
+pars2 = c(res,ddmodel,cond,btorph,0,soc,tol,maxiter)
 initloglik = dd_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,pars2 = pars2,brts = brts,missnumspec = missnumspec)
 cat("The likelihood for the inital parameter values is",initloglik,"\n")
 if(initloglik == -Inf)
