@@ -32,8 +32,15 @@ if(sum(brts == 0) == 0) { brts[length(brts) + 1] = 0 }
 soc = pars2[6]
 S = length(brts) + (soc - 2)
 ddep = pars2[2]
-if(min(pars1) < 0 || pars1[1] <= pars1[2] || pars1[3] <= (S + missnumspec)) { loglik = -Inf } else
+if(min(pars1) < 0)
 {
+    loglik = -Inf
+} else {
+if((pars1[2] == 0 && ddep == 2) || (pars1[1] == 0 && ddep == 4) || pars1[1] <= pars1[2])
+{ 
+    cat("These parameter values cannot satisfy lambda(N) = mu(N) for some finite N.\n")
+    loglik = -Inf
+} else {
     la = pars1[1]
     mu = pars1[2]
     K = pars1[3]
@@ -41,7 +48,6 @@ if(min(pars1) < 0 || pars1[1] <= pars1[2] || pars1[3] <= (S + missnumspec)) { lo
     cond = pars2[3]
     btorph = pars2[4]
 
-
     if((ddep == 1 || ddep == 5) && ceiling(la/(la - mu) * (r + 1) * K) < (S + missnumspec)) { loglik = -Inf } else
     {
        if(ddep == 1 || ddep == 5) { lx = min(max(1 + missnumspec,1 + ceiling(la/(la - mu) * (r + 1) * K)),round(pars2[1])) } else { lx = round(pars2[1]) }
@@ -59,14 +65,17 @@ if(min(pars1) < 0 || pars1[1] <= pars1[2] || pars1[3] <= (S + missnumspec)) { lo
               if(ddep == 2) { lavec = pmax(rep(0,lx),la * (((0:(lx-1))+k1) + 1)^(-log(la/mu)/log(K+1))) }
               if(ddep == 3 || ddep == 4) { lavec = la }    
               probs = lavec * probs # speciation event
-              if(sum(probs) <= 0) { loglik = -Inf } else
+              if(sum(probs) <= 0)
               {
+                 loglik = -Inf
+                 break
+              } else {
                  loglik = loglik + log(sum(probs))
               }
               probs = probs/sum(probs)
           }
        }    
-       if(probs[1+missnumspec]<=0) { loglik = -Inf } else
+       if(probs[1+missnumspec]<=0 || loglik == -Inf) { loglik = -Inf } else
        {        
           loglik = loglik + log(probs[1 + missnumspec]) - lgamma(S + missnumspec + 1) + lgamma(S + 1) + lgamma(missnumspec + 1)
   
@@ -86,7 +95,7 @@ if(min(pars1) < 0 || pars1[1] <= pars1[2] || pars1[3] <= (S + missnumspec)) { lo
           loglik = loglik - logliknorm
        }
     }
-}
+}}
 if(pars2[5] == 1)
 {
     s1 = sprintf('Parameters: %f %f %f',pars1[1],pars1[2],pars1[3])
